.. _module_hydra_lib_exceptions:

exceptions
==========

This sections contains module documentation of exceptions modules.

dependencyerror
^^^^^^^^^^^^^^^

Module provides custom exception class DependencyError (attributes error_num, args, message).
Unit tests available at hydratk/lib/exceptions/dependencyerror/01_methods_ut.jedi

inputerror
^^^^^^^^^^

Module provides custom exception class InputError (attributes error_num, args, message).
Unit tests available at hydratk/lib/exceptions/inputerror/01_methods_ut.jedi